# CueSplitter

[![License](https://img.shields.io/github/license/Olezhich/CueSplitter )](https://github.com/Olezhich/CueSplitter/blob/main/LICENSE )
[![Python](https://img.shields.io/badge/python-3.12%2B-blue)](https://python.org)  
[![Tests](https://github.com/Olezhich/CueSplitter/workflows/Tests/badge.svg )](https://github.com/Olezhich/CueSplitter/actions )

> **Lossless, bit-perfect splitting of FLAC albums using CUE sheets. PCM verification and automatic tagging**  
Parsing of Cue Sheets,
splitting albums into tracks, checking the bitwise equality of the original PSM stream of the album and the resulting PSM streams of the tracks and automatic tagging

## Features

## Changes

For a full list of updates, see the [CHANGELOG](CHANGELOG.md).

## QuickStart
### Installation of the library
#### Via pip

```bash
pip install cuesplitter
```

#### Via poetry
```bash
poetry add cuesplitter
```
### Using of the library
```python
```


## License
MIT